@@ -49,7 +49,7 @@ void ThemeEditorMainWindow::writeConfig()
 void ThemeEditorMainWindow::readConfig()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup group = KConfigGroup(config, "ThemeEditorMainWindow");
+    KConfigGroup group = KConfigGroup(config, QStringLiteral("ThemeEditorMainWindow"));
     const QSize sizeDialog = group.readEntry("Size", QSize(600, 400));
     if (sizeDialog.isValid()) {
         resize(sizeDialog);
@@ -325,3 +325,5 @@ void ThemeEditorMainWindow::slotSaveAsTheme()
         }
     }
 }
+
+#include "moc_themeeditormainwindow.cpp"
