@@ -5,7 +5,7 @@
 */
 #include "contactconfigurationdialog.h"
 #include "contacteditorutil.h"
-#include <KPIMTextEdit/PlainTextEditorWidget>
+#include <TextCustomEditor/PlainTextEditorWidget>
 
 #include "configurewidget.h"
 
@@ -41,12 +41,12 @@ ContactConfigureDialog::ContactConfigureDialog(QWidget *parent)
     auto lab = new QLabel(i18n("Default contact:"));
     lay->addWidget(lab);
 
-    mDefaultContact = new ContactEditor::AkonadiContactEditor(ContactEditor::AkonadiContactEditor::CreateMode, ContactEditor::AkonadiContactEditor::VCardMode);
+    mDefaultContact = new Akonadi::AkonadiContactEditor(Akonadi::AkonadiContactEditor::CreateMode, Akonadi::AkonadiContactEditor::VCardMode);
     lay->addWidget(mDefaultContact);
 
     tab->addTab(w, i18n("General"));
 
-    mDefaultTemplate = new KPIMTextEdit::PlainTextEditorWidget;
+    mDefaultTemplate = new TextCustomEditor::PlainTextEditorWidget;
     tab->addTab(mDefaultTemplate, i18n("Default Template"));
 
     auto mainLayout = new QVBoxLayout(this);
@@ -122,7 +122,7 @@ void ContactConfigureDialog::readConfig()
 
     mConfigureWidget->readConfig();
 
-    KConfigGroup group = KConfigGroup(config, "ContactConfigureDialog");
+    KConfigGroup group = KConfigGroup(config, QStringLiteral("ContactConfigureDialog"));
     const QSize sizeDialog = group.readEntry("Size", QSize(600, 400));
     if (sizeDialog.isValid()) {
         resize(sizeDialog);
@@ -141,3 +141,5 @@ void ContactConfigureDialog::writeConfig()
     group.writeEntry("defaultTemplate", mDefaultTemplate->toPlainText());
     mConfigureWidget->writeConfig();
 }
+
+#include "moc_contactconfigurationdialog.cpp"
