@@ -12,12 +12,12 @@ namespace GrantleeThemeEditor
 class ConfigureWidget;
 }
 
-namespace ContactEditor
+namespace Akonadi
 {
 class AkonadiContactEditor;
 }
 
-namespace KPIMTextEdit
+namespace TextCustomEditor
 {
 class PlainTextEditorWidget;
 }
@@ -35,6 +35,6 @@ private:
     void slotDefaultClicked();
     void slotOkClicked();
     GrantleeThemeEditor::ConfigureWidget *mConfigureWidget = nullptr;
-    KPIMTextEdit::PlainTextEditorWidget *mDefaultTemplate = nullptr;
-    ContactEditor::AkonadiContactEditor *mDefaultContact = nullptr;
+    TextCustomEditor::PlainTextEditorWidget *mDefaultTemplate = nullptr;
+    Akonadi::AkonadiContactEditor *mDefaultContact = nullptr;
 };
