@@ -48,7 +48,7 @@ void ContactEditorMainWindow::writeConfig()
 void ContactEditorMainWindow::readConfig()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup group = KConfigGroup(config, "ContactEditorMainWindow");
+    KConfigGroup group = KConfigGroup(config, QStringLiteral("ContactEditorMainWindow"));
     const QSize sizeDialog = group.readEntry("Size", QSize(600, 400));
     if (sizeDialog.isValid()) {
         resize(sizeDialog);
@@ -322,3 +322,5 @@ void ContactEditorMainWindow::slotSaveAsTheme()
         }
     }
 }
+
+#include "moc_contacteditormainwindow.cpp"
