@@ -8,7 +8,7 @@
 #include "contacttemplatewidget.h"
 #include "editorwidget.h"
 #include "previewwidget.h"
-#include <KPIMTextEdit/PlainTextEditor>
+#include <TextCustomEditor/PlainTextEditor>
 
 #include <KSplitterCollapserButton>
 
@@ -58,7 +58,7 @@ EditorPage::EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QSt
     connect(mEditor->editor(), &QPlainTextEdit::textChanged, this, &GrantleeThemeEditor::EditorPage::changed);
 
     if (mType == MainPage) {
-        KConfigGroup group(KSharedConfig::openConfig(), "EditorPage");
+        KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("EditorPage"));
         const QList<int> size{400, 100};
         mMainSplitter->setSizes(group.readEntry("mainSplitter", size));
         mWidgetSplitter->setSizes(group.readEntry("widgetSplitter", size));
@@ -68,7 +68,7 @@ EditorPage::EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QSt
 EditorPage::~EditorPage()
 {
     if (mType == MainPage) {
-        KConfigGroup group(KSharedConfig::openConfig(), "EditorPage");
+        KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("EditorPage"));
         group.writeEntry("mainSplitter", mMainSplitter->sizes());
         group.writeEntry("widgetSplitter", mWidgetSplitter->sizes());
     }
@@ -78,3 +78,5 @@ GrantleeThemeEditor::PreviewWidget *EditorPage::preview() const
 {
     return mPreview;
 }
+
+#include "moc_editorpage.cpp"
