@@ -82,9 +82,6 @@ void EditorPage::saveAsFilename(const QString &filename)
     QFile file(filename);
     if (file.open(QIODevice::WriteOnly | QIODevice::Text)) {
         QTextStream out(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        out.setCodec("UTF-8");
-#endif
         out << mEditor->toPlainText();
         file.close();
     } else {
@@ -108,3 +105,5 @@ void EditorPage::installTheme(const QString &themePath)
     const QString filename = themePath + QLatin1Char('/') + mPageFileName;
     saveAsFilename(filename);
 }
+
+#include "moc_editorpage.cpp"
