@@ -5,16 +5,16 @@
 */
 #pragma once
 
-#include <KPIMTextEdit/PlainTextEditor>
 #include <KSyntaxHighlighting/Repository>
+#include <TextCustomEditor/PlainTextEditor>
 
-namespace KPIMTextEdit
+namespace TextCustomEditor
 {
 class TextEditorCompleter;
 }
 namespace GrantleeThemeEditor
 {
-class GrantleePlainTextEditor : public KPIMTextEdit::PlainTextEditor
+class GrantleePlainTextEditor : public TextCustomEditor::PlainTextEditor
 {
     Q_OBJECT
 public:
@@ -27,7 +27,7 @@ protected:
     void keyPressEvent(QKeyEvent *e) override;
 
 protected:
-    KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter = nullptr;
+    TextCustomEditor::TextEditorCompleter *mTextEditorCompleter = nullptr;
 
 private:
     void initCompleter();
